from dataclasses import dataclass, field
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from nerualpha.providers.voice.contracts.IUser import IUser
from nerualpha.providers.voice.contracts.IChannel import IChannel


#interface
class ITransferMemberPayload(ABC):
    action:str
    channel:IChannel
    state:str
    user:IUser
